##  Related Information
  * [Business Capability Modeling Guidelines](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page covers modeling guidelines for business capabilities. Learn about best practices and applicable use cases, and avoid common antipatterns.")
  * [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.")


YesNo
Send
